@@ -1,4 +1,7 @@
 import configparser
+import copy
+from typing import Any
+from typing import Dict
 
 
 """
@@ -24,30 +27,37 @@ output=json
 """
 
 
-async def gather(hub, profiles):
+async def gather(hub) -> Dict[str, Any]:
     """
-    load profiles from unencrypted AWS credential files
+    load profiles from unencrypted AWS credential files.
+
+    Add "aws.iam" to the "acct.extras" section of your idem config file.
 
     Example:
     .. code-block:: yaml
 
-        aws.iam:
-            paths:
+        acct:
+          extras:
+            aws.iam:
+              paths:
                 - ~/.aws/credentials
                 - /path/to/other/credential/file
-            # Optional overrides
-            id: XXXXXXXXXXXXXXXXX
-            key: XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-            region: us-east-1
+              # Optional overrides
+              region: us-east-1
     """
     sub_profiles = {}
     config = configparser.ConfigParser()
 
-    ctx = profiles.get("aws.iam", {})
+    try:
+        ctx = copy.copy(hub.OPT.acct.extras.get("aws.iam", {}))
+    except AttributeError:
+        return sub_profiles
+
     credential_files = ctx.pop("paths", [])
     config.read(credential_files)
 
     for profile in set(config.sections()):
-        sub_profiles[profile] = ctx
+        sub_profiles[profile] = {name: value for name, value in config.items(profile)}
+        sub_profiles[profile].update(ctx)
 
     return sub_profiles
